##
##  mp4ff.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_mp4ff_base  0.29.0
%define       V_mp4ff_snap  20240324

#   package information
Name:         mp4ff
Summary:      MP4 Media Parsing Tools
URL:          https://github.com/edgeware/mp4ff
Vendor:       Edgeware
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      MIT
Version:      %{V_mp4ff_base}.%{V_mp4ff_snap}
Release:      20240324

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/mp4ff/mp4ff-%{V_mp4ff_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    mp4ff implements MP4 media file parsing and writing for AVC and
    HEVC video, AAC and AC-3 audio, and stpp and wvtt subtitles. It
    is focused on fragmented files as used for streaming in DASH, MSS
    and HLS fMP4, but can also decode and encode all boxes needed for
    progressive MP4 files. In particular, the tool mp4ff-crop can be
    used to crop a progressive file.

%track
    prog mp4ff = {
        version   = %{V_mp4ff_base}
        url       = https://github.com/edgeware/mp4ff/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n mp4ff

%build
    #   build program
    (   export GOPATH=`pwd`
        cd $GOPATH/src/github.com/edgeware/mp4ff
        go build -v -o mp4ff-crop       cmd/mp4ff-crop/*.go
        go build -v -o mp4ff-info       cmd/mp4ff-info/*.go
        go build -v -o mp4ff-nallister  cmd/mp4ff-nallister/*.go
        go build -v -o mp4ff-pslister   cmd/mp4ff-pslister/*.go
        go build -v -o mp4ff-wvttlister cmd/mp4ff-wvttlister/*.go
    ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/edgeware/mp4ff/mp4ff-crop \
        src/github.com/edgeware/mp4ff/mp4ff-info \
        src/github.com/edgeware/mp4ff/mp4ff-nallister \
        src/github.com/edgeware/mp4ff/mp4ff-pslister \
        src/github.com/edgeware/mp4ff/mp4ff-wvttlister \
        $RPM_BUILD_ROOT%{l_prefix}/bin/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

